@@ -14,15 +14,15 @@ class cdcc_rate(Variable):
         agi = tax_unit("adjusted_gross_income", period)
 
         # First phase-out
-        phase_out_agi = max_(0, agi - cdcc.phaseout.start)
-        percentage_reduction = np.ceil(cdcc.phaseout.rate * phase_out_agi)
+        phase_out_agi = max_(0, agi - cdcc.phase_out.start)
+        percentage_reduction = np.ceil(cdcc.phase_out.rate * phase_out_agi)
         phased_out_rate = max_(
-            cdcc.phaseout.min, cdcc.phaseout.max - percentage_reduction
+            cdcc.phase_out.min, cdcc.phase_out.max - percentage_reduction
         )
 
         # Second phase-out
-        second_phase_out_agi = max_(0, agi - cdcc.phaseout.second_start)
+        second_phase_out_agi = max_(0, agi - cdcc.phase_out.second_start)
         second_percentage_reduction = np.ceil(
-            cdcc.phaseout.rate * second_phase_out_agi
+            cdcc.phase_out.rate * second_phase_out_agi
         )
         return max_(0, phased_out_rate - second_percentage_reduction)
