@@ -20,7 +20,15 @@ class taxable_uc_agi(Variable):
             for income_source in gross_income_sources
             if income_source != "taxable_unemployment_compensation"
         ]
-        gross_income = add(tax_unit, period, income_sources_without_ss)
+        gross_income = 0
+        person = tax_unit.members
+        not_dependent = ~person("is_tax_unit_dependent", period)
+        for source in income_sources_without_ss:
+            # Add positive values only - losses are deducted later.
+            gross_income += not_dependent * max_(
+                0, add(person, period, [source])
+            )
+        gross_income = tax_unit.sum(gross_income)
         above_the_line_deductions = irs.ald.deductions
         total_deductions = add(tax_unit, period, above_the_line_deductions)
         return max_(0, gross_income - total_deductions)
