@@ -14,7 +14,7 @@ class additional_medicare_tax(Variable):
     def formula(tax_unit, period, parameters):
         amc = parameters(period).irs.payroll.medicare.additional
         # Wage and self-employment income are taxed the same.
-        ELEMENTS = ["filer_e00200", "taxable_self_employment_income"]
+        ELEMENTS = ["employment_income", "taxable_self_employment_income"]
         wages_plus_se = add(tax_unit, period, ELEMENTS)
         exclusion = amc.exclusion[tax_unit("filing_status", period)]
         base = max_(0, wages_plus_se - exclusion)
