@@ -3,7 +3,7 @@ from openfisca_us.model_api import *
 
 class rent(Variable):
     value_type = float
-    entity = SPMUnit
+    entity = Person
     label = "Rent"
     unit = USD
     definition_period = YEAR
